@@ -2,7 +2,7 @@ import unittest
 
 from scrapy.http import Request
 from scrapy.spider import BaseSpider
-from scrapy.core.exceptions import IgnoreRequest
+from scrapy.exceptions import IgnoreRequest
 from scrapy.contrib.schedulermiddleware.duplicatesfilter import DuplicatesFilterMiddleware
 
 
@@ -10,7 +10,7 @@ class DuplicatesFilterMiddlewareTest(unittest.TestCase):
 
     def setUp(self):
         self.mw = DuplicatesFilterMiddleware()
-        self.spider = BaseSpider()
+        self.spider = BaseSpider('foo')
         self.mw.open_spider(self.spider)
 
     def tearDown(self):
